<?php
/*
Plugin Name: Newspool
Plugin URI: http://www.newspool.io
Description: www.newspool.io içerik okuyucu. XML'den verileri okur, resim dosyasını indirir ve içerikle birlikte yayınlar.
Version: 1.0
Author: RTurk Teknoloji
*/

// Eklenti ana sayfası
function newspool_admin_page() {
    // Varsayılan değerler
    $defaults = array(
        'feed_url' => '',
        'tracking_type' => 'main_category',
        'publish_type' => 'publish_now',
        'cron_interval' => '5',
        'default_user' => 0  // Yeni kullanıcı seçimi için varsayılan değer
    );

    // Kayıtlı ayarları al
    $options = get_option('newspool_options', $defaults);

    // Form gönderildiğinde ayarları güncelle
    if ($_SERVER["REQUEST_METHOD"] == "POST") {
        // Formdan gelen verileri al
        $options['feed_url'] = $_POST["feed_url"];
        $options['tracking_type'] = $_POST["tracking_type"];
        $options['publish_type'] = $_POST["publish_type"];
        $options['cron_interval'] = $_POST["cron_interval"];
        $options['default_user'] = isset($_POST["default_user"]) ? intval($_POST["default_user"]) : 0;

        // Ayarları güncelle
        update_option('newspool_options', $options);
        echo '<div class="updated"><p>Ayarlar başarıyla kaydedildi!</p></div>';
    }

    // Kullanıcıları listele
    $users = get_users();
    ?>

    <div class="wrap">
        <h2>Newspool Eklenti Ayarları</h2>
        <p>Bu eklenti www.newspool.io içerik okuyucudur. XML'den verileri okur, resim dosyasını indirir ve içerikle birlikte yayınlar.</p>
        <form method="post" action="">
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="feed_url">Feed URL</label></th>
                    <td><input type="text" id="feed_url" name="feed_url" value="<?php echo esc_attr($options['feed_url']); ?>" class="regular-text" /></td>
                </tr>
                <tr>
                    <th scope="row"><label for="tracking_type">Takip Türü</label></th>
                    <td>
                        <select id="tracking_type" name="tracking_type">
                            <option value="main_category" <?php selected($options['tracking_type'], 'main_category'); ?>>Ana Kategori Takibi</option>
                            <option value="sub_category" <?php selected($options['tracking_type'], 'sub_category'); ?>>Alt Kategori Takibi</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="publish_type">Yayınlama Türü</label></th>
                    <td>
                        <select id="publish_type" name="publish_type">
                            <option value="publish_now" <?php selected($options['publish_type'], 'publish_now'); ?>>Hemen Yayınla</option>
                            <option value="draft" <?php selected($options['publish_type'], 'draft'); ?>>Taslak Olarak Kaydet</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="cron_interval">Wp Cron Aralığı</label></th>
                    <td>
                        <select id="cron_interval" name="cron_interval">
                            <option value="5" <?php selected($options['cron_interval'], '5'); ?>>5 Dakika</option>
                            <option value="10" <?php selected($options['cron_interval'], '10'); ?>>10 Dakika</option>
                            <option value="15" <?php selected($options['cron_interval'], '15'); ?>>15 Dakika</option>
                            <option value="30" <?php selected($options['cron_interval'], '30'); ?>>30 Dakika</option>
                            <option value="60" <?php selected($options['cron_interval'], '60'); ?>>1 Saat</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="default_user">İçerik Sahibi Kullanıcı</label></th>
                    <td>
                        <select id="default_user" name="default_user">
                            <?php foreach ($users as $user) {
                                echo '<option value="' . esc_attr($user->ID) . '"' . selected($options['default_user'], $user->ID) . '>' . esc_html($user->display_name) . '</option>';
                            } ?>
                        </select>
                    </td>
                </tr>
            </table>
            <?php submit_button('Ayarları Kaydet'); ?>
        </form>
    </div>
    <?php
}


// Eklenti menüsünün oluşturulması
function newspool_plugin_menu() {
    add_menu_page('Haberyaz', 'Haberyaz Ayarlar', 'manage_options', 'newspool-settings', 'newspool_admin_page');
    add_submenu_page(
        'newspool-settings',                  // Üst menü slug
        'Kategori Eşleştirmesi',             // Sayfa başlığı
        'Kategori Eşleştirmesi',             // Menü adı
        'manage_options',                     // Gerekli yetki seviyesi
        'newspool-category-mappings',         // Alt menü slug
        'newspool_category_mappings_page'     // Sayfa içeriği gösteren fonksiyon
    );
    add_submenu_page(
        'newspool-settings',
        'Hemen Feed İşleme',
        'Hemen Feed İşleme',
        'manage_options',
        'newspool-process',
        'newspool_process_page'
    );
    add_submenu_page('newspool-settings', 'Wp-Cron Başlat', 'Wp-Cron Başlat', 'manage_options', 'newspool-start', 'start_reading_process');
    add_submenu_page('newspool-settings', 'Wp-Cron Durdur', 'Wp-Cron Durdur', 'manage_options', 'newspool-stop', 'stop_reading_process');

    // Kategori Eşleştirmesi için yeni bir alt menü ekliyoruz
    
}

function newspool_process_page() {
    echo '<div class="wrap">';
    echo '<h2>Feed İşlem Sonuçları</h2>';

    if (isset($_POST['start_process'])) {
        process_feed(); // İşlemi burada tetikle
    } else {
        echo '<form method="post">';
        echo '<input type="submit" name="start_process" class="button button-primary" value="Feed İşlemi Başlat">';
        echo '</form>';
    }

    echo '</div>';
}

function newspool_category_mappings_page() {
    if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['category_mappings'])) {
        // POST verilerini güvenli bir şekilde işle
        $new_mappings = array_map('intval', $_POST['category_mappings']);
        update_option('newspool_category_mappings', $new_mappings);
        echo '<div class="updated"><p>Kategori eşleştirmeleri başarıyla kaydedildi!</p></div>';
    }

    $saved_mappings = get_option('newspool_category_mappings', array());
    $categories = get_categories(array('hide_empty' => false));

    echo '<div class="wrap"><h1>Kategori Eşleştirmeleri</h1><form method="post" action="">';
    echo '<table class="wp-list-table widefat fixed striped"><thead><tr><th>WP Kategori Adı</th><th>WP Kategori ID</th><th>Feed Category ID</th></tr></thead><tbody>';

    foreach ($categories as $category) {
        $category_id = $category->term_id;
        $mapping_value = isset($saved_mappings[$category_id]) ? $saved_mappings[$category_id] : '';
        echo "<tr><td>{$category->name}</td><td>{$category->term_id}</td><td><input type='text' name='category_mappings[{$category->term_id}]' value='{$mapping_value}' /></td></tr>";
    }

    echo '</tbody></table>';
    submit_button('Ayarları Kaydet');
    echo '</form></div>';
}



// Başlatma işlevi
function start_reading_process() {
    $options = get_option('newspool_options');
    if ($options && isset($options['feed_url'])) {
        wp_schedule_single_event(time(), 'newspool_process_feed');
        echo '<div class="updated"><p>Okuma işlemi başlatıldı!</p></div>';
    }
}

// Durdurma işlevi
function stop_reading_process() {
    $timestamp = wp_next_scheduled('newspool_process_feed');
    wp_unschedule_event($timestamp, 'newspool_process_feed');
    echo '<div class="updated"><p>Okuma işlemi durduruldu!</p></div>';
}

// WordPress cron ile tetiklenecek olan fonksiyon
add_action('newspool_process_feed', 'process_feed');

// Feed işleme fonksiyonu
function process_feed() {
    $options = get_option('newspool_options');
    $author_id = isset($options['default_user']) ? $options['default_user'] : get_current_user_id();
    $category_mappings = get_option('newspool_category_mappings', array()); // Kategori eşleştirmelerini yükleyin
    $rss = simplexml_load_file($options['feed_url']);

    if (!$rss) {
        echo 'Feed yüklenemedi!';
        return;
    }

    echo "<h2>İşlenen İçerikler</h2>";
    echo "<ul>";

    foreach ($rss->channel->item as $item) {
        $guid = (string) $item->guid;
        $baslik = (string) $item->title;
        $etiket = (string) $item->etiket;
        $existing_post_id = check_post_exists_by_guid($guid);
        
        if ($existing_post_id) {
            echo "<li>$baslik - haberi zaten var.</li>";
            continue; // Bu GUID ile bir post zaten varsa, atla
        }
        else {
	    // Etiket string'inden virgüller ve '#' işaretleri kaldırılır
$etiketler = str_replace(',', ' ', $etiket);  // Virgülleri boşlukla değiştir
$etiketler = str_replace('#', '', $etiketler); // '#' işaretlerini kaldır

// Boşluklarla ayrılmış kelimeleri ayır
$etiketler = explode(' ', $etiketler);

// Boş değerleri ve fazladan boşlukları temizle
$etiketler = array_filter($etiketler, function($value) {
    return !empty(trim($value));
});

       $category_mappings = get_option('newspool_category_mappings', array());

// Diziyi ters çevir
$flipped_mappings = array_flip($category_mappings);

// Aranan WordPress kategori ID'si
$gelenkategoriid = (string) $item->categoryID; // Burada $item->categoryID bir WordPress kategori ID'si olduğunu varsayıyoruz

// Ters çevrilmiş dizide doğrudan arama yap
if (isset($flipped_mappings[$gelenkategoriid])) {
    $sonucid = $flipped_mappings[$gelenkategoriid];
   
} 
        
        // Kategori ID'yi göstermek için daha açık bir mesaj ekle
        echo "<li>İşlenen Haber: $baslik - Gelen kategori : " . $gelenkategoriid . " - Kategori ID: $sonucid</li>";

        $post_data = [
            'post_title'    => $baslik,
            'post_content'  => (string) $item->description,
            'post_status'   => $options['publish_type'] === 'publish_now' ? 'publish' : 'draft',
            'post_date'     => date('Y-m-d H:i:s', strtotime($item->pubDate)),
            'post_category' => [$sonucid], // Bu kısım array olmalıdır
            'post_author'   => $author_id,
            'meta_input'    => ['guid' => $guid],
            'tax_input'     => [
        'post_tag' => $etiketler // İşlenmiş etiketler
    ]
        ];
        if ($post_data !== null) {

        
        $post_id = wp_insert_post($post_data);
        $post_data = null;
        echo "<li>$baslik - haberi eklendi.</li>";

        if (!empty($item->image)) {
            require_once(ABSPATH . 'wp-admin/includes/media.php');
            require_once(ABSPATH . 'wp-admin/includes/file.php');
            require_once(ABSPATH . 'wp-admin/includes/image.php');

            $image_url = (string) $item->image;
            $image_id = media_sideload_image($image_url, $post_id, null, 'id');
            if (is_wp_error($image_id)) {
                echo "<li>Resim yükleme hatası: " . $image_id->get_error_message() . "</li>";
            } else {
                set_post_thumbnail($post_id, $image_id);
            }
        }
  }
         echo "<li><hr/></li>";
         }
    }

    echo "</ul>";
}

function check_post_exists_by_guid($guid) {
    global $wpdb;
    $sql = $wpdb->prepare("SELECT post_id FROM {$wpdb->postmeta} WHERE meta_key = 'guid' AND meta_value = %s LIMIT 1", $guid);
    return $wpdb->get_var($sql);
}

// Cron işlemi ayarlama
function setup_feed_cron_job() {
    $options = get_option('newspool_options');
    if (!wp_next_scheduled('newspool_process_feed')) {
        wp_schedule_event(time(), 'hourly', 'newspool_process_feed'); // Saatlik olarak ayarlanabilir
    }
}

add_action('newspool_process_feed', 'process_feed');
add_action('wp', 'setup_feed_cron_job');


add_action('admin_menu', 'newspool_plugin_menu');
?>
